/**
 * Quoridor server and related libraries
 * Copyright (C) 2009-2010 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */

package cz.xelfi.quoridor.webidor;

import java.util.Date;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlValue;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
@XmlAccessorType(XmlAccessType.FIELD)
public class Note {
    @XmlValue
    private String comment;
    @XmlAttribute
    private Date when;
    @XmlAttribute
    private String who;

    private Note() {
    }

    public Note(String comment, Date when, String who) {
        this.comment = comment;
        this.when = new Date(when.getTime());
        this.who = who;
    }

    public String getComment() {
        return comment;
    }

    public Date getWhen() {
        return (Date) when.clone();
    }

    public String getWho() {
        return who;
    }

    @Override
    public String toString() {
        return "Note[" + who + "@" + when + ": " + comment + "]";
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Note other = (Note) obj;
        if ((this.comment == null) ? (other.comment != null) : !this.comment.equals(other.comment)) {
            return false;
        }
        if (this.when != other.when && (this.when == null || !this.when.equals(other.when))) {
            return false;
        }
        if ((this.who == null) ? (other.who != null) : !this.who.equals(other.who)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 59 * hash + (this.comment != null ? this.comment.hashCode() : 0);
        hash = 59 * hash + (this.when != null ? this.when.hashCode() : 0);
        hash = 59 * hash + (this.who != null ? this.who.hashCode() : 0);
        return hash;
    }


}
